mailRe: r8331 - /branches/relax_disp/specific_fns/relax_disp.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by Sébastien Morin on January 08, 2009 - 02:08:
Hi,

I don't know if this is the good way to do it, but as I plan it, I would
use different functions whether the user chooses cpmg or r1rho. The
equivalent of cpmg_frq (for CPMG pulse train frequency in, Hz) would be
r1rho_strength (for R1rho spin lock strength, in Hz).

Associated to CPMG experiments would be specific equations for fast and
slow exchange. Other specific functions (also for fast and slow
exchange) would be associated to R1rho experiments.

I don't know if this separation of concepts is necessary at this point.

What do you think ?

Thanks.


Seb  :)




sebastien.morin.1@xxxxxxxxx wrote:
Author: semor
Date: Thu Jan  8 00:48:34 2009
New Revision: 8331

URL: http://svn.gna.org/viewcvs/relax?rev=8331&view=rev
Log:
Changed 'relax_time' instances to 'cpmg_frq'.


Modified:
    branches/relax_disp/specific_fns/relax_disp.py

Modified: branches/relax_disp/specific_fns/relax_disp.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/specific_fns/relax_disp.py?rev=8331&r1=8330&r2=8331&view=diff
==============================================================================
--- branches/relax_disp/specific_fns/relax_disp.py (original)
+++ branches/relax_disp/specific_fns/relax_disp.py Thu Jan  8 00:48:34 2009
@@ -122,7 +122,7 @@
 
             # Intensity scaling.
             elif search('^i', spin.params[i]):
                 # Find the position of the first time point.
frequency point.
                 pos = cdp.cpmg_frqs.index(min(cdp.cpmg_frqs))
 
                 # Scaling.
@@ -135,15 +135,15 @@
         return scaling_matrix
 
 
-    def back_calc(self, spin=None, relax_time_index=None):
-        """Back-calculation of peak intensity for the given relaxation 
time.
-
-        @keyword spin:              The spin container.
-        @type spin:                 SpinContainer instance
-        @keyword relax_time_index:  The index for the desired relaxation 
time.
-        @type relax_time_index:     int
-        @return:                    The peak intensity for the desired 
relaxation time.
-        @rtype:                     float
+    def back_calc(self, spin=None, cpmg_frq_index=None):
+        """Back-calculation of peak intensity for the given CPMG pulse 
train frequency.
+
+        @keyword spin:            The spin container.
+        @type spin:               SpinContainer instance
+        @keyword cpmg_frq_index:  The index for the desired CPMG pulse 
train frequency.
+        @type cpmg_frq_index:     int
+        @return:                  The peak intensity for the desired CPMG 
pulse train frequency.
+        @rtype:                   float
         """
 
         # Alias the current data pipe.
@@ -165,7 +165,7 @@
         results = back_calc_I()
 
         # Return the correct peak height.
-        return results[relax_time_index]
+        return results[cpmg_frq_index]
 
 
     def cpmg_frq(self, frq=0, spectrum_id=None):
@@ -239,7 +239,7 @@
         # Loop over the spectral time points.
         for j in xrange(len(cdp.cpmg_frqs)):
             # Back calculate the value.
-            value = self.back_calc(spin=spin, relax_time_index=j)
+            value = self.back_calc(spin=spin, cpmg_frq_index=j)
 
             # Append the value.
             mc_data.append(value)
@@ -122,7 +122,7 @@
             # Intensity scaling.
             elif search('^i', spin.params[i]):
-                # Find the position of the first time point.
+                # Find the position of the first CPMG pulse train 
frequency point.
                 pos = cdp.cpmg_frqs.index(min(cdp.cpmg_frqs))


_______________________________________________
relax (http://nmr-relax.com)

This is the relax-commits mailing list
relax-commits@xxxxxxx

To unsubscribe from this list, get a password
reminder, or change your subscription options,
visit the list information page at
https://mail.gna.org/listinfo/relax-commits

  




Related Messages


Powered by MHonArc, Updated Thu Jan 08 11:20:15 2009